@@ -11,7 +11,11 @@ class BioSamples:
         self.encoder = SampleEncoder()
 
     def send_sample(self, sample: Sample):
+        self.__clear_aap_token()
         payload = self.encoder.default(sample)
         if sample.accession:
             return self.biosamples.update_sample(sample=payload, jwt=self.aap.get_token())
         return self.biosamples.persist_sample(sample=payload, jwt=self.aap.get_token())
+
+    def __clear_aap_token(self):
+        self.aap.token = None
